// Copyright (C) 2018 Avatao.com Innovative Learning Kft.
// All Rights Reserved. See LICENSE file for details.

import { Component, OnInit } from '@angular/core';
import { WebSocketService } from '../services/websocket.service';
import { ConsoleCommand } from './console-command';
import { config } from '../config';

@Component({
  selector: 'app-console',
  templateUrl: './console.component.html',
  styleUrls: ['./console.component.scss']
})
export class ConsoleComponent implements OnInit {
  console_content: string = config.console.defaultContent;

  command_handlers = {
    'write': this.writeHandler.bind(this),
    'read':  this.readHandler.bind(this)
  };

  constructor(private webSocketService: WebSocketService) {}

  ngOnInit() {
    this.webSocketService.connect();
    this.webSocketService.observeKey<ConsoleCommand>('console').subscribe((event) => {
      this.command_handlers[event.data.command](event.data);
    });
  }

  writeHandler(data: ConsoleCommand) {
    this.setContent(data.content);
  }

  readHandler(data: ConsoleCommand) {
    this.sendContent(this.console_content);
  }

  newLogHandler(content: string) {
    if (config.console.rewriteContentWithNewLogs) {
      this.setContent(content);
    }
  }

  setContent(content: string) {
    this.console_content = content;
  }

  sendContent(content: string) {
    this.webSocketService.send('console', {
      'command': 'read',
      'content': content
    });
  }
}
